export const VersionBadge = ({ version }) => {
    return (
        <Badge stroke size='lg' icon='gift' iconType='regular' className="version-badge">
            New in version <code>{version}</code>
        </Badge>
    );
};